@@ -49,7 +49,7 @@ protected:
 //    				QDBusMessage msg = dbusPhone.call( "CreateWith", f->value, (uint)0 );
 
     				QDBusMessage msg = QDBusMessage::createMethodCall(
-    				        "com.nokia.csd.Call", // --dest
+    				        "", //"com.nokia.csd.Call", // --dest
     				        "/com/nokia/csd/call", // destination object path
     				        "com.nokia.csd.Call", // message name (w/o method)
     				        "CreateWith" // method
@@ -59,8 +59,10 @@ protected:
     				msg = QDBusConnection::systemBus().call(msg);
 
     				qDebug() << msg;
+/*
+dbus-send --system --type=method_call --print-reply --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:"$NUMBER" uint32:0
 
-    				    //    			dbus-send --system --type=method_call --print-reply --dest=com.nokia.csd.Call /com/nokia/csd/call com.nokia.csd.Call.CreateWith string:"$NUMBER" uint32:0
+ */
     			}
     			else {
 #ifdef Q_WS_MAEMO_5
