@@ -39,7 +39,10 @@ public:
 
 	void resetF ();
 	void keyPressEvent(QKeyEvent* event);
+#ifdef Q_WS_MAEMO_5
 	void orientationChanged(int o);
+#endif
+	void focus ();
 
 private slots:
 	void select(const QString& a);
